==> huaweicloudsdkidentitycenter-3.1.131-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/get_custom_role_for_permission_set_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class GetCustomRoleForPermissionSetResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'custom_role': 'str'
    }

    attribute_map = {
        'custom_role': 'custom_role'
    }

    def __init__(self, custom_role=None):
        """GetCustomRoleForPermissionSetResponse

        The model defined in huaweicloud sdk

        :param custom_role: 附加到权限集的自定义策略
        :type custom_role: str
        """
        
        super(GetCustomRoleForPermissionSetResponse, self).__init__()

        self._custom_role = None
        self.discriminator = None

        if custom_role is not None:
            self.custom_role = custom_role

    @property
    def custom_role(self):
        """Gets the custom_role of this GetCustomRoleForPermissionSetResponse.

        附加到权限集的自定义策略

        :return: The custom_role of this GetCustomRoleForPermissionSetResponse.
        :rtype: str
        """
        return self._custom_role

    @custom_role.setter
    def custom_role(self, custom_role):
        """Sets the custom_role of this GetCustomRoleForPermissionSetResponse.

        附加到权限集的自定义策略

        :param custom_role: The custom_role of this GetCustomRoleForPermissionSetResponse.
        :type custom_role: str
        """
        self._custom_role = custom_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCustomRoleForPermissionSetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkidentitycenter-3.1.150-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/get_custom_role_for_permission_set_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class GetCustomRoleForPermissionSetResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'custom_role': 'str'
    }

    attribute_map = {
        'custom_role': 'custom_role'
    }

    def __init__(self, custom_role=None):
        r"""GetCustomRoleForPermissionSetResponse

        The model defined in huaweicloud sdk

        :param custom_role: 附加到权限集的自定义策略
        :type custom_role: str
        """
        
        super(GetCustomRoleForPermissionSetResponse, self).__init__()

        self._custom_role = None
        self.discriminator = None

        if custom_role is not None:
            self.custom_role = custom_role

    @property
    def custom_role(self):
        r"""Gets the custom_role of this GetCustomRoleForPermissionSetResponse.

        附加到权限集的自定义策略

        :return: The custom_role of this GetCustomRoleForPermissionSetResponse.
        :rtype: str
        """
        return self._custom_role

    @custom_role.setter
    def custom_role(self, custom_role):
        r"""Sets the custom_role of this GetCustomRoleForPermissionSetResponse.

        附加到权限集的自定义策略

        :param custom_role: The custom_role of this GetCustomRoleForPermissionSetResponse.
        :type custom_role: str
        """
        self._custom_role = custom_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCustomRoleForPermissionSetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
